﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;

namespace XamGrid_ComboBox
{
    public class ViewModel : ObservableModel
    {
        private ObservableCollection<Data> customData;
        private ObservableCollection<OptionElement> optionsList;

        public ViewModel()
        {
            GridData = GenerateData(3);
            OptionsList = GenerateOptions();
        }

        public ObservableCollection<Data> GridData
        {
            get
            {
                return customData;
            }

            set
            {
                this.customData = value;
                NotifyPropertyChanged();
            }
        }
        public ObservableCollection<OptionElement> OptionsList
        {
            get
            {
                return optionsList;
            }

            set
            {
                this.optionsList = value;
                NotifyPropertyChanged();
            }
        }

        private ObservableCollection<Data> GenerateData(int dataCount)
        {
            ObservableCollection<Data> customData = new ObservableCollection<Data>();

            for (int i = 1; i <= dataCount; i++)
            {
                customData.Add(new Data { Name = "Item " + i, Description = "Description " + i, Count = i + 10, Options = "Type One,Type Two,Type Three" });
            }

            return customData;
        }
        
        private ObservableCollection<OptionElement> GenerateOptions()
        {
            List<string> list = GridData.First().Options.Split(',').ToList();
            ObservableCollection<OptionElement> optionsList = new ObservableCollection<OptionElement>();

            foreach (var item in list)
            {
                optionsList.Add(new OptionElement { Type = item });
            }
            return optionsList;
        }
    }

    public class Data : ObservableModel
    {
        private string name;
        private string description;
        private int count;
        private string options;


        public string Name
        {
            get
            {
                return name;
            }

            set
            {
                if (value != this.name)
                {
                    this.name = value;
                    NotifyPropertyChanged();
                }
            }
        }

        public string Description
        {
            get
            {
                return description;
            }

            set
            {
                if (value != this.description)
                {
                    this.description = value;
                    NotifyPropertyChanged();
                }
            }
        }

        public int Count
        {
            get
            {
                return count;
            }

            set
            {
                if (value != this.count)
                {
                    this.count = value;
                    NotifyPropertyChanged();
                }
            }
        }

        public string Options
        {
            get
            {
                return options;
            }

            set
            {
                if (value != this.options)
                {
                    this.options = value;
                    NotifyPropertyChanged();
                }
            }
        }
    }
}




